#
# spec file for package rsibreak
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_ver 0.12
%bcond_without released
Name:           rsibreak
Version:        0.12.15
Release:        2.2
Summary:        Repetetive Strain Injury recovery and prevention assistance utility
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/rsibreak
Source0:        https://download.kde.org/stable/rsibreak/%{base_ver}/rsibreak-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/rsibreak/%{base_ver}/rsibreak-%{version}.tar.xz.sig
Source2:        rsibreak.keyring
%endif
BuildRequires:  extra-cmake-modules >= 5.79.0
BuildRequires:  fdupes
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IdleTime)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5NotifyConfig)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5DBus) >= 5.10.0
BuildRequires:  cmake(Qt5Test) >= 5.10.0
Requires:       hicolor-icon-theme
Recommends:     rsibreak-lang = %{version}
Obsoletes:      rsibreak-doc < %{version}

%description
Repetitive Strain Injury is an illness which can occur as a result of
working with a mouse and keyboard. This utility can be used to remind
you to take a break now and then.

%lang_package

%prep
%setup -q

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name

%{kf5_find_htmldocs}

%fdupes %{buildroot}%{_kf5_sharedir}

%files lang -f %{name}.lang

%files
%license LICENSES/*
%doc AUTHORS ChangeLog NEWS
%doc %{_kf5_htmldir}/en/
%{_kf5_applicationsdir}/org.kde.rsibreak.desktop
%{_kf5_appstreamdir}/org.kde.rsibreak.appdata.xml
%{_kf5_bindir}/rsibreak
%{_kf5_configdir}/autostart/rsibreak_autostart.desktop
%{_kf5_dbusinterfacesdir}/org.rsibreak.rsiwidget.xml
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_notifydir}/rsibreak.notifyrc

%changelog
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
- Spec cleanup
* Sun Jun 12 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.12.15:
  * Add option to suppress breaks while fullscreen windows are
    visible
  * Potentially fix tooltip rendering on XFCE
  * Make it possible to disable tiny breaks
  * Configuration dialog: Don't reset timers when pressing "OK" if
    no changes happened
  * Translation improvements
  * Convert license headers to SPDX
  * Internal code improvements
- Add signature file and keyring
* Tue Jun 29 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.12.14:
  * Translation improvements
  * Minor code cleanup
- Remove no longer used KF5IconThemes BuildRequires
* Sat Apr 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update URL.
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Sun Apr  5 2020 wbauer@tmo.at
- Update to 0.12.13:
  * Fix crash in some configurations
  * Translation improvements
  * Minor code cleanup
* Sun Mar 29 2020 wbauer@tmo.at
- Update to 0.12.12:
  * Don't reset pause counter on very short inputs that can just be
    accidental
  * Improve high dpi support
  * Translation improvements
  * Compile with Qt 5.15 beta
  * Minor code cleanup
* Sat Sep 21 2019 wbauer@tmo.at
- Update to 0.12.11:
  * Improve notification integration with the notification KCM
  * Translation improvements
  * Minor code cleanup
- Switch Qt5/KF5 BuildRequires to cmake() style
* Sun Jun 30 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summaries.
* Thu Jun 20 2019 wbauer@tmo.at
- Update to 0.12.10:
  * Added appdata file
  * Translation improvements
  * Minor internal refactoring
- Use %%kf5_find_htmldocs macro to generate the translated docs
  filelist
- Remove ldconfig calls in %%post/%%postun, the package doesn't
  install shared libraries
* Tue Oct  9 2018 wbauer@tmo.at
- Update to 0.12.9:
  * Fixed some notifications not triggering (kde#396270)
  * Translation improvements
  * Minor internal refactoring
- Mark license files with %%license instead of %%doc
- Run spec-cleaner
* Mon Feb 12 2018 wbauer@tmo.at
- Update to 0.12.8:
  * Translation improvements
  * Free the user if hibernation happened while the countdown was
    shown (kde#384783)
  * Slideshow: add the ability to select how to keep aspect ratio
    for image
  * Add pause skip threshold
* Thu May  4 2017 wbauer@tmo.at
- Update to 0.12.7:
- Changes from 0.12.6:
  * Translation improvements
  * Fix notification trigger when they should not. (kde#377419)
  * Fix popup menu text when resuming/suspending via dbus. (kde#378918)
  * Show/hide the relax popup when suspending/resuming. (kde#378995)
- Changes from 0.12.5:
  * Translation improvements
  * Fix saving changes made to the notifications in the settings dialog. (kde#375931)
- Changes from 0.12.4:
  * Translation improvements
  * Documentation typo fix
- Changes from 0.12.3:
  * Fix memory leak when using the slide show effect
  * Translation improvements
  * Documentation improvements
* Thu Aug  4 2016 asterios.dramis@gmail.com
- Update to 0.12.3:
  * ChangeLog not available.
- Added build requirements kcrash-devel, pkgconfig(Qt5Core),
  pkgconfig(Qt5Gui) and pkgconfig(Qt5Widgets).
- Removed build requirement pkgconfig(Qt5X11Extras).
- Merged doc and lang subpackages since doc holds the translated
  helpfiles. Moved english help file to main package. Obsolete the
  doc subpackage.
* Mon Nov  9 2015 tchvatal@suse.com
- Version bump to 0.12:
  * KF5 based version
  * Basically quite rewrite
  * No plasma widget anymore
  * Works with plasma5
* Wed Jul 24 2013 hrvoje.senjan@gmail.com
- BuildRequire only libkde4-devel, instead of kdebase4-workspace-devel
* Mon Sep 19 2011 idonmez@suse.com
- Recommend the -lang package
* Tue Sep 13 2011 toddrme2178@gmail.com
- Removed test for obsolete openSUSE version (fix for RPMLINT warning)
- Split doc package (fix for RPMLINT warning)
- Split lang package (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Mon Aug 29 2011 mlin@suse.com
- few fixes for RPMLINT warnings
  * translated desktop files
  * do not obsoletes itself
  * add %%fdupes macro for fix files duplicated
- clean up the specfile formatting
* Sat Jan 15 2011 wstephenson@novell.com
- Update to 0.11
  * add button to defer break
  * Fix detection of additional screens
  * Make popup time configurable
  * Require Qt 4.6.0 and KDE 4.4.0
  * Fix timers when lock button is pressed
  * Add the possibility to remove the lock button
  * Remove buggy screenshot to show RSIBreak in the systray at
    startup and when launching a second time
  * Add notification settings to the config
  * Don't restart timers when leaving config and timers has not
    been changed
  * Slideshoweffect: make the visibility of small images optional
  * Make popup visibly more attractive
  * Make timers work for Qt=>4.4
  * Fix plasma category
  * Use KIdle library from kdelibs, instead of directly asking X
* Mon Feb 15 2010 llunak@novell.com
- fix build with gcc-4.5
* Fri Jul 24 2009 toma@kde.org
- New upstream version 0.10:
  - Use kdelibs function for display duration of a time.
  - Fixed all effects to work on xinerama
  - Fixed Plasma effect to work for KDE < 4.3
  - Fixed Slideshow effect
  - Fixed Welcome screen for KDE < 4.4
  - Fixed bug which resulted in multiple popups
    telling that the timer has been reset
  - Renamed No Full Screen effect to Popup effect
  - Renamed Gray effect to Black effect if no compositing is available
* Sun Jul 12 2009 toma@kde.org
- New upstream version 0.10 beta 1:
  - Fixed several porting bugs
  - Rewrote most off the full screen break effects
  - Some memory leaks fixed
  - Genral stabilization and improved user experience
* Fri May  8 2009 dmueller@suse.de
- fix build with cmake 2.6.4
* Sun Apr 26 2009 beineri@opensuse.org
- document and limit doc directory work-arounds
* Sat Jan 17 2009 coolo@suse.de
- fix build with plasma from 4.2
* Tue Dec  9 2008 stbinner@suse.de
- drop obsolete patches to install Plasma applet and documentation
* Fri Nov 28 2008 stbinner@suse.de
- update to 0.9.0 final: only version bump and translation updates
* Sun Nov  9 2008 stbinner@suse.de
- fix build on ppc
* Wed Nov  5 2008 dmueller@suse.de
- add missing runtime dependencies
* Tue Oct 28 2008 wstephenson@suse.de
- update to 0.9.0-beta5
  * Install autostart file in correct location
  * Fix plasma applet
  * Respect 'presentation mode' by monitoring the freedesktop.org
    screensaver setting
  * Try to detect waking up from hibernation so timers can be reset
  * Fix welcome screen
  * Fix bug where timer did not count down in a slideshow
  * Fix build on non-x86 platforms
* Mon Oct 20 2008 stbinner@suse.de
- fix build on archs without mmx
* Thu Oct  9 2008 wstephenson@suse.de
- update to 0.9.0-beta4
  * Fix bugs in config dialog layouts
* Thu Jun 26 2008 dmueller@suse.de
- update to 0.9.0-beta3
  * porting to KDE4
* Sun Oct 15 2006 stbinner@suse.de
- Update to version 0.8
  * Replaced DCOP dialog with a more flexible and standardized
    interface to attach events to breaks
  * Show where RSIBreak is located in the tray when started a
    second time.
  * RSIBreak now has a manual.
  * Option to only reset timers when idle for the duration of a
    long break.
  * Skip button in relax popup
  * Xinerama fixes
    Images smaller than 1/3 of the screen will not be used for
    the slideshow
  * Some tiny optimizations and bugfixes
* Tue Jun 20 2006 stbinner@suse.de
- Update to version 0.7.1
  * New icons from Lee Olson.
  * Usability review from Tina Trillitzsch.
  * Two new DCOP calls: doTinyBreak and doBigBreak.
  * New statistics: percentage of activity during the last minute,
    last hour and last 6 hours.
  * Inform the user when the next break will be a big break.
  * Ability to make DCOP calls to the start and end of breaks.
  * Possibility to use KDCOP to set that up.
  * Possibility to break at fixed times.
* Tue May 30 2006 adrian@suse.de
- fix build for < 10.1
* Tue Apr 11 2006 stbinner@suse.de
- Update to version 0.6
* Wed Apr  5 2006 stbinner@suse.de
- Initial package (version 0.6 rc1)
